@@ -196,6 +196,9 @@ def unpack_key( ) :
     if( ( key_parts[ 1 ] != "*" ) ) :
         url = key_parts[ 1 ]
         if( url[ 0:4 ] != "http" ) : url = "https://" + url
+        purl = s_util.url_parse(url)
+        if(purl.port==None):
+            url=url+":443"
         #set_key_alt( "endpoint/url" , url )
         set_key( "endpoint/url" , url )
 
@@ -210,10 +213,12 @@ def unpack_key( ) :
     # FIXME TODO do not use ALT config ?
 
     #s_log.write(url)
-    #purl = s_util.url_parse(url)
+#    purl = s_util.url_parse(url)
     #s_log.write(purl.scheme)
     #s_log.write(purl.hostname)
-    #s_log.write(purl.port)
+#    s_log.write(purl.port)
+#    if(purl.port==None):
+
 
 
     return
